@@ -4,6 +4,8 @@
 #include	<sys/stat.h>
 #include	<fcntl.h>
 #include	<stdio.h>
+#include	<stdlib.h>
+#include	<string.h>
 #include	<signal.h>
 
 
