@@ -1,6 +1,11 @@
 
 /* A program to remove the doubled letters in nroff -man output */
 
+/* This program was written before I learned the trick:
+
+	nroff -man file.man | col -b
+*/
+
 #include	<stdio.h>
 
 main()
